@@ -15,15 +15,15 @@ Provides a formatting facility for log messages
       timestamp_format => "%Y-%m-%d %H:%M:%S"
     );
 
-    # by default, the handle will set its formatter to
+    # By default, the handle will set its formatter to
     # Log::Fine::Formatter::Basic.  If that's not what you want, set
     # it to preference.
     $handle->formatter($formatter);
 
-    # set the time-stamp to "YYYY-MM-DD HH:MM:SS"
+    # Set the time-stamp to "YYYY-MM-DD HH:MM:SS"
     $formatter->timeStamp("%Y-%m-%d %H:%M:%S");
 
-    # high resolution timestamps with milliseconds are
+    # High resolution timestamps with milliseconds are
     # supported thus:
     my $hires_formatter =
       Log::Fine::Formatter::Basic->new(
@@ -124,10 +124,15 @@ sub format
         my $self  = shift;
         my $class = ref $self;
 
-        $self->_fatal("direct call to abstract method format()!")
-            if $class eq 'Log::Fine::Formatter';
+        if ($class eq 'Log::Fine::Formatter') {
+                $self->_fatal("direct call to abstract method format()!");
+        } else {
+                $self->_fatal("call to abstract method ${class}::format()");
+        }
 
-        $self->_fatal("call to abstract method ${class}::format()");
+        #
+        # NOT REACHED
+        #
 
 }          # format()
 
@@ -212,24 +217,24 @@ sub _init
 
         my $self = shift;
 
-        # perform super initializations
+        # Perform any necessary upper class initializations
         $self->SUPER::_init();
 
-        # verify that we can load the Time::HiRes module
+        # Verify that we can load the Time::HiRes module
         if ($self->{hires}) {
 
                 eval "require Time::HiRes";
-                $self->_fatal(
-"Time::HiRes failed to load.  Please install Time::HiRes via CPAN : $@"
-                ) if $@;
+                $self->_fatal(  "Time::HiRes failed to load.  "
+                              . "Please install Time::HiRes via CPAN : $@")
+                    if $@;
 
-                # set {timestamp_format} to default high precision
+                # Set {timestamp_format} to default high precision
                 # format if necessary.
                 $self->{timestamp_format} = $self->LOG_TIMESTAMP_FORMAT_PRECISE
                     unless (defined $self->{timestamp_format}
                             and $self->{timestamp_format} =~ /\w+/);
 
-                # set {precision} to default if necessary
+                # Set {precision} to default if necessary
                 $self->{precision} = $self->LOG_TIMESTAMP_DEFAULT_PRECISION
                     unless (defined $self->{precision}
                             and $self->{precision} =~ /^\d+$/);
@@ -239,14 +244,13 @@ sub _init
 
         } else {
 
-                # set {timestamp_format} to the default if necessary
+                # Set {timestamp_format} to the default if necessary
                 $self->{timestamp_format} = $self->LOG_TIMESTAMP_FORMAT
                     unless (defined $self->{timestamp_format}
                             and $self->{timestamp_format} =~ /\w+/);
 
         }
 
-        # Victory!
         return $self;
 
 }          # _init()
@@ -276,7 +280,6 @@ sub _formatTime
                 $seconds = time;
         }
 
-        # return the formatted time
         return strftime($fmt, localtime($seconds));
 
 }          # _formatTime()
@@ -284,7 +287,7 @@ sub _formatTime
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-log-fine-record at rt.cpan.org>, or through the web interface at
+C<bug-log-fine at rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Log-Fine>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
@@ -319,7 +322,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: 215b8b16e3214a0a1f9347605a45756af7eb12fe $
+  $Id: a54afd03edc820a3e1467ea4ee49797d5b585bd1 $
 
 =head1 AUTHOR
 
@@ -331,7 +334,7 @@ L<perl>, L<strftime>, L<Log::Fine>, L<Time::HiRes>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008, 2009, 2010 Christopher M. Fuhrman, 
+Copyright (c) 2008-2010, 2013 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
