@@ -10,16 +10,16 @@ Sets up an output handle for log messages
     use Log::Fine;
     use Log::Fine::Handle;
 
-    # instantiate the handle (default values shown)
+    # Instantiate the handle (default values shown)
     my $handle = Log::Fine::Handle::Foo
         ->new( name      => "foo0",
                mask      => Log::Fine::Handle->DEFAULT_LOGMASK,
                formatter => Log::Fine::Formatter:Basic->new() );
 
-    # see if a handle is loggable at a given level
+    # See if a handle is loggable at a given level
     my $rc = $handle->isLoggable(INFO);
 
-    # write a message
+    # Write a message
     $handle->msgWrite(INFO, "Informational message", 1);
 
 =head1 DESCRIPTION
@@ -64,7 +64,7 @@ sub bitmaskListEnabled
         my $map      = $self->levelMap();
         my @bitmasks = ();
 
-        # reminder: log() here is the perl logarithmic function (see
+        # Reminder: log() here is the perl logarithmic function (see
         # perlfunc(3)) and is not to be confused with the name of this
         # module ;)
         foreach my $maskname ($map->logMasks()) {
@@ -103,10 +103,13 @@ sub formatter
         my $self      = shift;
         my $formatter = shift;
 
-        # if the first argument is a valid formatter, then set the
+        # Should the first argument is a valid formatter, then set the
         # objects formatter attribute appropriately
         $self->{formatter} = $formatter
-            if (defined $formatter and $formatter->isa("Log::Fine::Formatter"));
+            if (    defined $formatter
+                and ref $formatter
+                and UNIVERSAL::can($formatter, 'isa')
+                and $formatter->isa("Log::Fine::Formatter"));
 
         # return the objects formatter attribute
         return $self->{formatter};
@@ -142,7 +145,7 @@ sub isLoggable
         # Return undef if level is not defined
         return unless defined $lvl;
 
-        # convert level to value if we are given a string, otherwise
+        # Convert level to value if we are given a string, otherwise
         # use value as is.
         my $val =
             ($lvl =~ /^\d+$/) ? $lvl : $self->levelMap()->levelToValue($lvl);
@@ -152,7 +155,7 @@ sub isLoggable
 
         my $shifted = 2 << $val;
 
-        # bitand the level and the mask to see if we're loggable
+        # Bitand the level and the mask to see if we're loggable
         return (($self->{mask} & $shifted) == $shifted) ? 1 : undef;
 
 }          # isLoggable()
@@ -197,7 +200,7 @@ sub msgWrite
 
         my $msg =
             ($class eq 'Log::Fine::Handle')
-            ? "direct call to abstract method msgWrite()!\n  See ${class} documentation"
+            ? "direct call to abstract method msgWrite()!\n  See Log::Fine::Handle documentation"
             : "call to abstract method ${class}::msgWrite()";
 
         $self->_fatal($msg);
@@ -218,19 +221,20 @@ sub _init
 
         my $self = shift;
 
-        # perform super initializations
+        # Perform any necessary upper class initializations
         $self->SUPER::_init();
 
-        # set default bitmask
+        # Set default bitmask
         $self->{mask} = $self->levelMap()->bitmaskAll()
             unless defined $self->{mask};
 
-        # set the default formatter
+        # Set the default formatter
         $self->{formatter} = Log::Fine::Formatter::Basic->new()
-            unless (defined $self->{formatter}
+            unless (    defined $self->{formatter}
+                    and ref $self->{formatter}
+                    and UNIVERSAL::can($self->{formatter}, 'isa')
                     and $self->{formatter}->isa("Log::Fine::Formatter"));
 
-        # Victory!
         return $self;
 
 }          # _init()
@@ -273,7 +277,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: 9de32f36b06f627623e05f437937062559173187 $
+  $Id: 183ab6a22e38a840713bb8c6dccc7cb2c0595477 $
 
 =head1 AUTHOR
 
@@ -285,7 +289,7 @@ L<perl>, L<Log::Fine>, L<Log::Fine::Formatter>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008, 2010-2011 Christopher M. Fuhrman, 
+Copyright (c) 2008, 2010-2011, 2013 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
